HIP: enable mfma mmq on gfx908 and gfx90a for select datatypes and shapes (#14949)

This commit is contained in:
uvos
2025-07-30 17:38:06 +02:00
committed by GitHub
parent e32a4ec60e
commit ad4a700117
3 changed files with 25 additions and 10 deletions
+2 -2
View File
@@ -3096,8 +3096,8 @@ static __global__ void mul_mat_q(
}
__syncthreads();
// On AMD or old CUDA the performance with stream-k was worse, use conventional tiling instead:
#if (defined(GGML_USE_HIP) && !defined(CDNA3)) || __CUDA_ARCH__ < GGML_CUDA_CC_VOLTA
// On non-CDNA AMD or old CUDA the performance with stream-k was worse, use conventional tiling instead:
#if (defined(GGML_USE_HIP) && !defined(CDNA)) || __CUDA_ARCH__ < GGML_CUDA_CC_VOLTA
{
const int wt = blockIdx.z / nchannels_y;
const int zt = blockIdx.z - wt*nchannels_y;